pub struct StyleFlags(/* private fields */);Implementations
Sourceimpl StyleFlags
impl StyleFlags
pub const BOLD: StyleFlags
pub const ITALIC: StyleFlags
pub const BOLD_ITALIC: StyleFlags
pub const REVERSE: StyleFlags
Sourceimpl StyleFlags
impl StyleFlags
Sourcepub const fn empty() -> StyleFlags
pub const fn empty() -> StyleFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> StyleFlags
pub const fn all() -> StyleFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<StyleFlags>
pub const fn from_bits(bits: u8) -> Option<StyleFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> StyleFlags
pub const fn from_bits_truncate(bits: u8) -> StyleFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> StyleFlags
pub const fn from_bits_retain(bits: u8) -> StyleFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<StyleFlags>
pub fn from_name(name: &str) -> Option<StyleFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: StyleFlags) -> bool
pub const fn intersects(&self, other: StyleFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: StyleFlags) -> bool
pub const fn contains(&self, other: StyleFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: StyleFlags)
pub fn insert(&mut self, other: StyleFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: StyleFlags)
pub fn remove(&mut self, other: StyleFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: StyleFlags)
pub fn toggle(&mut self, other: StyleFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: StyleFlags, value: bool)
pub fn set(&mut self, other: StyleFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: StyleFlags) -> StyleFlags
pub const fn intersection(self, other: StyleFlags) -> StyleFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: StyleFlags) -> StyleFlags
pub const fn union(self, other: StyleFlags) -> StyleFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: StyleFlags) -> StyleFlags
pub const fn difference(self, other: StyleFlags) -> StyleFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: StyleFlags) -> StyleFlags
pub const fn symmetric_difference(self, other: StyleFlags) -> StyleFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> StyleFlags
pub const fn complement(self) -> StyleFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl StyleFlags
impl StyleFlags
Sourcepub const fn iter(&self) -> Iter<StyleFlags>
pub const fn iter(&self) -> Iter<StyleFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StyleFlags>
pub const fn iter_names(&self) -> IterNames<StyleFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.